@@ -7,16 +7,24 @@ int Process::precompile()
     string const &spch = d_options.spch();
     string const &spchGch = d_options.spchGch();
 
+//xerr("spchGch: " << spchGch << ", spch: " << spch);
+
     bool ok = recent(spchGch, spch);
     if (not ok)
     {
+        string compilerSpec = 
+                    Tools::compilerSpec(d_options.compilerArg(), 
+                                        s_precompileCmd);
+
+        if (size_t pos = compilerSpec.find(" -x"); pos != string::npos)
+            compilerSpec = compilerSpec.substr(0, pos) +
+                            d_options.extraOptions() + 
+                            compilerSpec.substr(pos);
+
+//xerr("compiler spec. = `" << compilerSpec << '\'');
+
         Exec exec;
-        exec.execute(
-                Tools::command(
-                    Tools::compilerSpec(d_options.arg1(), s_precompileCmd),
-                    spch, spchGch
-                )
-            );
+        exec.execute(Tools::command(compilerSpec, spch, spchGch));
         ok =  exec.ret() == 0;
     }
 
